@@ -19,22 +19,32 @@ from time import sleep
 
 import pytest
 
-from pygls.lsp.methods import INITIALIZE, TEXT_DOCUMENT_DID_OPEN, WORKSPACE_EXECUTE_COMMAND
-from pygls.lsp.types import (ClientCapabilities, DidOpenTextDocumentParams, ExecuteCommandParams,
-                             InitializeParams, TextDocumentItem)
+from pygls import IS_PYODIDE
+from pygls.lsp.methods import (
+    INITIALIZE,
+    TEXT_DOCUMENT_DID_OPEN,
+    WORKSPACE_EXECUTE_COMMAND,
+)
+from pygls.lsp.types import (
+    ClientCapabilities,
+    DidOpenTextDocumentParams,
+    ExecuteCommandParams,
+    InitializeParams,
+    TextDocumentItem,
+)
 from pygls.protocol import LanguageServerProtocol
 from pygls.server import LanguageServer
-from tests import CMD_ASYNC, CMD_SYNC, CMD_THREAD
-
-CALL_TIMEOUT = 2
+from . import CMD_ASYNC, CMD_SYNC, CMD_THREAD
 
 
 def _initialize_server(server):
-    server.lsp.lsp_initialize(InitializeParams(
-        process_id=1234,
-        root_uri=pathlib.Path(__file__).parent.as_uri(),
-        capabilities=ClientCapabilities(),
-    ))
+    server.lsp.lsp_initialize(
+        InitializeParams(
+            process_id=1234,
+            root_uri=pathlib.Path(__file__).parent.as_uri(),
+            capabilities=ClientCapabilities(),
+        )
+    )
 
 
 def test_bf_initialize(client_server):
@@ -48,12 +58,12 @@ def test_bf_initialize(client_server):
             "processId": process_id,
             "rootUri": root_uri,
             "capabilities": ClientCapabilities(),
-        }
-    ).result(timeout=CALL_TIMEOUT)
+        },
+    ).result()
 
     assert server.process_id == process_id
     assert server.workspace.root_uri == root_uri
-    assert 'capabilities' in response
+    assert "capabilities" in response
 
 
 def test_bf_text_document_did_open(client_server):
@@ -61,56 +71,57 @@ def test_bf_text_document_did_open(client_server):
 
     _initialize_server(server)
 
-    client.lsp.notify(TEXT_DOCUMENT_DID_OPEN,
-                      DidOpenTextDocumentParams(
-                          text_document=TextDocumentItem(uri=__file__,
-                                                         language_id='python',
-                                                         version=1,
-                                                         text='test')))
+    client.lsp.notify(
+        TEXT_DOCUMENT_DID_OPEN,
+        DidOpenTextDocumentParams(
+            text_document=TextDocumentItem(
+                uri=__file__, language_id="python", version=1, text="test"
+            )
+        ),
+    )
 
     sleep(1)
 
     assert len(server.lsp.workspace.documents) == 1
 
+    document = server.workspace.get_document(__file__)
+    assert document.uri == __file__
+    assert document.version == 1
+    assert document.source == "test"
+    assert document.language_id == "python"
 
+
+@pytest.mark.skipif(IS_PYODIDE, reason='threads are not available in pyodide.')
 def test_command_async(client_server):
     client, server = client_server
 
-    is_called, thread_id = client.lsp.send_request(WORKSPACE_EXECUTE_COMMAND,
-                                                   ExecuteCommandParams(
-                                                       command=CMD_ASYNC
-                                                   ))\
-        .result(timeout=CALL_TIMEOUT)
+    is_called, thread_id = client.lsp.send_request(
+        WORKSPACE_EXECUTE_COMMAND, ExecuteCommandParams(command=CMD_ASYNC)
+    ).result()
 
     assert is_called
     assert thread_id == server.thread_id
 
 
+@pytest.mark.skipif(IS_PYODIDE, reason='threads are not available in pyodide.')
 def test_command_sync(client_server):
     client, server = client_server
 
-    is_called, thread_id = \
-        client.lsp.send_request(
-            WORKSPACE_EXECUTE_COMMAND,
-            ExecuteCommandParams(
-                command=CMD_SYNC
-            )
-        ).result(timeout=CALL_TIMEOUT)
+    is_called, thread_id = client.lsp.send_request(
+        WORKSPACE_EXECUTE_COMMAND, ExecuteCommandParams(command=CMD_SYNC)
+    ).result()
 
     assert is_called
     assert thread_id == server.thread_id
 
 
+@pytest.mark.skipif(IS_PYODIDE, reason='threads are not available in pyodide.')
 def test_command_thread(client_server):
     client, server = client_server
 
-    is_called, thread_id = \
-        client.lsp.send_request(
-            WORKSPACE_EXECUTE_COMMAND,
-            ExecuteCommandParams(
-                command=CMD_THREAD
-            )
-        ).result(timeout=CALL_TIMEOUT)
+    is_called, thread_id = client.lsp.send_request(
+        WORKSPACE_EXECUTE_COMMAND, ExecuteCommandParams(command=CMD_THREAD)
+    ).result()
 
     assert is_called
     assert thread_id != server.thread_id
